@@ -99,8 +99,8 @@ class BasicValidation:
             его валидности, а так же после вызова метода is_valid(self).
         """
         logger.warning(
-            "DEPRECATED: Instance method 'instance.get_errors()' is deprecated. "
-            "Support for this method will end in version 2.0. "
+            "DEPRECATED: Instance method 'instance.get_errors()' is "
+            "deprecated. Support for this method will end in version 2.0. "
             "Use a separate function "
             "'from validated_dc import get_errors', "
             "and 'get_errors(instance)'."
@@ -132,7 +132,7 @@ class BasicValidation:
         """
         self._errors__vdc = {}
 
-    def _is_instance(self, value: Any, annotation: type) -> bool:
+    def _is_instance__vdc(self, value: Any, annotation: type) -> bool:
         """
             Проверка значения на соответствие типу.
         """
@@ -145,7 +145,7 @@ class BasicValidation:
             result = False
 
         if not result:
-            self._field_errors.append(BasicValidationError(
+            self._field_errors__vdc.append(BasicValidationError(
                 value_repr=get_value_repr(value), value_type=type(value),
                 annotation=annotation, exception=exception
             ))
@@ -156,25 +156,27 @@ class BasicValidation:
         """
             Инициализация валидации для текущего поля
         """
-        self._field_errors = []
-        self._field_name = field.name
-        self._field_value = getattr(self, field.name)
-        self._field_annotation = field.type
+        self._field_errors__vdc = []
+        self._field_name__vdc = field.name
+        self._field_value__vdc = getattr(self, field.name)
+        self._field_annotation__vdc = field.type
 
-    def _is_field_valid(self, field: DataclassesField) -> bool:
+    def _is_field_valid__vdc(self, field: DataclassesField) -> bool:
         """
-            Запускает проверку поля
+            Запускает проверку поля, и возвращает результат валидации.
         """
         self._init_field_validation(field)
 
-        return self._is_instance(self._field_value, self._field_annotation)
+        return self._is_instance__vdc(
+            self._field_value__vdc, self._field_annotation__vdc
+        )
 
     def _save_current_field_errors(self) -> None:
         """
             Записывает ошибки текущего поля в self._errors
             (в ошибки всего экземпляра)
         """
-        self._errors__vdc[self._field_name] = self._field_errors
+        self._errors__vdc[self._field_name__vdc] = self._field_errors__vdc
 
     def _run_validation(self) -> None:
         """
@@ -183,7 +185,7 @@ class BasicValidation:
         self._init_validation()
 
         for field in dataclasses_fields(self):
-            if not self._is_field_valid(field):
+            if not self._is_field_valid__vdc(field):
                 self._save_current_field_errors()
 
 
@@ -232,11 +234,11 @@ class InstanceValidation(BasicValidation):
         # Выполнять ли замену словаря на экземпляр класса-потомка
         # InstanceValidation из аннотации поля (в случае пригодности
         # словаря для создания такого экземпляра), или Нет.
-        self._replace = True
+        self._is_replace__vdc = True
 
         self._replaced_field_names = []
 
-    def _is_instance(self, value: Any, annotation: type) -> bool:
+    def _is_instance__vdc(self, value: Any, annotation: type) -> bool:
 
         is_type = type(annotation) == type
         if is_type and issubclass(annotation, InstanceValidation):
@@ -258,38 +260,38 @@ class InstanceValidation(BasicValidation):
                     exception = exc
 
                 if errors is None and exception is None:
-                    self._replacement = instance
+                    self._replacement__vdc = instance
                     return True
 
-                self._field_errors.append(InstanceValidationError(
+                self._field_errors__vdc.append(InstanceValidationError(
                     value_repr=get_value_repr(value), value_type=type(value),
                     annotation=annotation, exception=exception, errors=errors
                 ))
                 return False
 
-        return super()._is_instance(value, annotation)
+        return super()._is_instance__vdc(value, annotation)
 
     def _init_field_validation(self, field: DataclassesField) -> None:
 
         super()._init_field_validation(field)
 
         # Свойство предназначенное для замены словаря
-        self._replacement = None
+        self._replacement__vdc = None
 
     def _try_replacing(self) -> None:
         """
             Пытается заменить значение у текущего поля на текущее значение
-            свойства self._replacement.
+            свойства self._replacement__vdc.
         """
         # Если включен флаг замены и есть чем заменять, то установим
         # новое значение у поля
-        if self._replace and self._replacement is not None:
-            setattr(self, self._field_name, self._replacement)
-            self._replaced_field_names.append(self._field_name)
+        if self._is_replace__vdc and self._replacement__vdc is not None:
+            setattr(self, self._field_name__vdc, self._replacement__vdc)
+            self._replaced_field_names.append(self._field_name__vdc)
 
-    def _is_field_valid(self, field: DataclassesField) -> bool:
+    def _is_field_valid__vdc(self, field: DataclassesField) -> bool:
 
-        result = super()._is_field_valid(field)
+        result = super()._is_field_valid__vdc(field)
 
         if result:
             # Попробуем произвести замену
@@ -339,7 +341,7 @@ class TypingValidation(InstanceValidation):
 
         Поддерживаемые алиасы перечислены в константе STR_ALIASES.
     """
-    def _is_instance(self, value: Any, annotation: type) -> bool:
+    def _is_instance__vdc(self, value: Any, annotation: type) -> bool:
 
         str_annotation = str(annotation)
 
@@ -348,7 +350,7 @@ class TypingValidation(InstanceValidation):
             if not self._is_supported_alias(str_annotation):
 
                 exception = TypeError('Alias is not supported!')
-                self._field_errors.append(TypingValidationError(
+                self._field_errors__vdc.append(TypingValidationError(
                     value_repr=get_value_repr(value), value_type=type(value),
                     annotation=annotation, exception=exception
                 ))
@@ -363,11 +365,13 @@ class TypingValidation(InstanceValidation):
                     return True
                 else:
                     if self._typing_field_error is not None:
-                        self._field_errors.append(self._typing_field_error)
+                        self._field_errors__vdc.append(
+                            self._typing_field_error
+                        )
                         self._typing_field_error = None
                     return False
 
-        return super()._is_instance(value, annotation)
+        return super()._is_instance__vdc(value, annotation)
 
     @staticmethod
     def _is_typing_alias(annotation: str) -> bool:
@@ -415,7 +419,7 @@ class TypingValidation(InstanceValidation):
         """
         # У Union допустимые типы перечислены в кортеже __args__
         for item_annotation in annotation.__args__:
-            if self._is_instance(value, item_annotation):
+            if self._is_instance__vdc(value, item_annotation):
                 return True
         # Нет ни одного типа, подходящего для value
         return False
@@ -437,13 +441,13 @@ class TypingValidation(InstanceValidation):
             # У List допустимый тип стоит первым в кортеже __args__
             annotation = annotation.__args__[0]
             for i, item_value in enumerate(value):
-                if self._is_instance(item_value, annotation):
+                if self._is_instance__vdc(item_value, annotation):
                     # Собираем новый список для текущего поля
                     # (так как в нем возможна замена элемента-словаря на
                     # элемент-экземпляр потомка родительского класса)
-                    if self._replacement:
-                        item_value = self._replacement
-                        self._replacement = False
+                    if self._replacement__vdc:
+                        item_value = self._replacement__vdc
+                        self._replacement__vdc = False
                     new_value.append(item_value)
                 else:
                     self._typing_field_error = ListValidationError(
@@ -453,7 +457,7 @@ class TypingValidation(InstanceValidation):
                     return False
 
             # Все элементы списка value валидные.
-            self._replacement = new_value
+            self._replacement__vdc = new_value
             return True
 
         self._typing_field_error = BasicValidationError(
